package com.usky.oa.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.common.security.utils.SecurityUtils;
import com.usky.oa.domain.OaApproval;
import com.usky.oa.domain.OaDocument;
import com.usky.oa.mapper.OaApprovalMapper;
import com.usky.oa.service.OaApprovalService;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.oa.service.vo.OaApprovalCountVO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.List;

/**
 * <p>
 * 审批表 服务实现类
 * </p>
 *
 * @author fu
 * @since 2024-12-10
 */
@Service
public class OaApprovalServiceImpl extends AbstractCrudService<OaApprovalMapper, OaApproval> implements OaApprovalService {

    @Autowired
    private OaApprovalMapper oaApprovalMapper;

    @Override
    public OaApprovalCountVO approvalCount() {
        Long userId = SecurityUtils.getUserId();
        String username = SecurityUtils.getUsername();
        Integer tenantId = SecurityUtils.getTenantId();

        OaApprovalCountVO oaApprovalCountVO = new OaApprovalCountVO();
        oaApprovalCountVO.setPendingSum(getPendingSum().size());

        LambdaQueryWrapper<OaApproval> queryWrapper1 = Wrappers.lambdaQuery();
        queryWrapper1.eq(OaApproval::getTenantId, tenantId)
                .eq(OaApproval::getApprovalUid, userId)
                .and(wrapper -> wrapper
                        .eq(OaApproval::getStatus, 1)
                        .or()
                        .eq(OaApproval::getStatus, 2));
        Integer count1 = oaApprovalMapper.selectCount(queryWrapper1);
        oaApprovalCountVO.setAlreadySum(count1);

        LambdaQueryWrapper<OaApproval> queryWrapper2 = Wrappers.lambdaQuery();
        queryWrapper2.eq(OaApproval::getTenantId, tenantId).eq(OaApproval::getCreateBy, username);
        Integer count2 = oaApprovalMapper.selectCount(queryWrapper2);
        oaApprovalCountVO.setMyInitiated(count2);

        LambdaQueryWrapper<OaApproval> queryWrapper3 = Wrappers.lambdaQuery();
        queryWrapper3.eq(OaApproval::getTenantId, tenantId)
                .eq(OaApproval::getApprovalUid, userId);
        Integer count3 = oaApprovalMapper.selectCount(queryWrapper3);
        oaApprovalCountVO.setMyReceived(count3);

        return oaApprovalCountVO;
    }

    private List<OaApproval> getPendingSum(){
        LambdaQueryWrapper<OaApproval> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(OaApproval::getTenantId, SecurityUtils.getTenantId())
                .eq(OaApproval::getApprovalUid, SecurityUtils.getUserId())
                .eq(OaApproval::getStatus, 0);
        List<OaApproval> oaApprovals = oaApprovalMapper.selectList(queryWrapper);
        return oaApprovals == null ? Collections.emptyList() : oaApprovals;
    }

}
